require 'rf_app_serializer/phase'
require "active_support/core_ext/hash/indifferent_access"

class RfAppSerializer
  attr_accessor :phases

  def initialize(phases)
    @phases = phases.each_with_index.map do |phase, index|
      Phase.new(
        name: phase.with_indifferent_access[:name],
        steps: phase.with_indifferent_access[:steps],
        index: index
      )
    end
  end

  def active_phase
    {
      name: find_active_phase.name,
      index: find_active_phase.index
    }
  end

  def active_step
    find_active_phase.active_step
  end

  private

  def find_active_phase
    phases.find { |phase| phase.is_current? } || last_completed_phase
  end

  # For out of sync applications (i.e, NLS)
  def last_completed_phase
    phases.find { |phase| phase.most_recent_step }
  end
end
