require "active_support/core_ext/hash/indifferent_access"

class Phase
  attr_accessor :name, :steps, :index

  def initialize(name:, steps:, index:)
    @name = name
    @steps = steps
    @index = index
  end

  def is_complete?
    steps.all? { |step| step.with_indifferent_access[:completed_at] }
  end

  def is_started?
    steps.any? { |step| step.with_indifferent_access[:started_at] }
  end

  def is_current?
    is_started? && !is_complete?
  end

  def active_step
    most_recent_step.with_indifferent_access[:name]
  end

  def most_recent_step
    in_process_step || last_completed_step
  end

  def in_process_step
    steps.find { |step| step.with_indifferent_access[:started_at] && !step.with_indifferent_access[:completed_at] }
  end

  def last_completed_step
    steps.select { |step| step.with_indifferent_access[:completed_at] }.last
  end
end
